==> nextcloud-app-mail-0.6.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/oc.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Mail",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n messatge novèl dins {folderName}\nde {from}","%n messatges novèls dins {folderName}\nde {from}"],
    "Error while loading the accounts." : "Error al moment del cargament dels comptes.",
    "Error while loading the selected account." : "Error al moment del cargament del compte seleccionat.",
    "Error while loading messages." : "Error al moment del cargament dels messatges.",
    "Error while loading the selected message." : "Error al moment del cargament del messatge seleccionat.",
    "Forwarded message" : "Messatge transferit",
    "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
    "Attachments saved to Files." : "Pèças juntas enregistradas dins los Fichièrs.",
    "Attachment saved to Files." : "Pèça junta enregistrada dins los Fichièrs.",
    "Error while saving attachments to Files." : "Error al moment de l'enregistrament de las pèças juntas dins los Fichièrs.",
    "Error while saving attachment to Files." : "Error al moment de l'enregistrament de la pèça junta dins los Fichièrs.",
    "Unknown error" : "Error desconeguda",
    "Error while creating an account: " : "Error al moment de la creacion del compte :",
    "Error while deleting account." : "Error al moment de la supression del compte.",
    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
    "Reply" : "Respondre",
    "Send" : "Mandar",
    "Sending …" : "Mandadís ...",
    "Message sent!" : "Messatge mandat !",
    "Server error" : "Error del servidor",
    "Opening HTML drafts is not supported yet." : "La dobertura de borrolhons al format HTML es pas presa en carga pel moment.",
    "Draft saved!" : "Borrolhon salvat!",
    "you" : "vos",
    "Send message to {email}" : "Mandar un mail a {email}",
    "Error while deleting message." : "Error al moment de la supression del messatge.",
    "Connecting" : "Connexion",
    "Connect" : "Connectar",
    "Inbox" : "Bóstia de recepcion",
    "Sent" : "Mandats",
    "Drafts" : "Borrolhons",
    "Archive" : "Archius",
    "Trash" : "Escobilhièr",
    "Junk" : "Indesirables",
    "All" : "Totes",
    "Favorites" : "Favorits",
    "Creating account failed: " : "La creacion del compte a fracassat :",
    "Auto detect failed. Please use manual mode." : "L'autodeteccion a fracassat. Utilizatz lo mòde manual.",
    "Delete permanently" : "Suprimir definitivament",
    "& others" : "e d'autres",
    "All inboxes" : "Totas las bóstias",
    "Error loading message" : "Error al moment del cargament del messatge",
    "Forwarding you to %s - click here if you are not automatically redirected within the next few seconds." : "Anatz èsser redirigit cap a %s - Clicatz aicí se sètz pas redirigit dins las segondas que seguisson.",
    "Continue to %s" : "Contunhar cap a %s"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-mail-0.7.10-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/oc.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Mail",
    "Error while loading the accounts." : "Error al moment del cargament dels comptes.",
    "Error while loading the selected account." : "Error al moment del cargament del compte seleccionat.",
    "Error while deleting message." : "Error al moment de la supression del messatge.",
    "Forwarded message" : "Messatge transferit",
    "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
    "Attachments saved to Files." : "Pèças juntas enregistradas dins los Fichièrs.",
    "Attachment saved to Files." : "Pèça junta enregistrada dins los Fichièrs.",
    "Error while saving attachments to Files." : "Error al moment de l'enregistrament de las pèças juntas dins los Fichièrs.",
    "Error while saving attachment to Files." : "Error al moment de l'enregistrament de la pèça junta dins los Fichièrs.",
    "Unknown error" : "Error desconeguda",
    "All inboxes" : "Totas las bóstias",
    "you" : "vos",
    "Send message to {email}" : "Mandar un mail a {email}",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Error while deleting account." : "Error al moment de la supression del compte.",
    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
    "Reply" : "Respondre",
    "Send" : "Mandar",
    "Sending …" : "Mandadís ...",
    "Message sent!" : "Messatge mandat !",
    "Server error" : "Error del servidor",
    "Opening HTML drafts is not supported yet." : "La dobertura de borrolhons al format HTML es pas presa en carga pel moment.",
    "& others" : "e d'autres",
    "Error while loading messages." : "Error al moment del cargament dels messatges.",
    "Inbox" : "Bóstia de recepcion",
    "Sent" : "Mandats",
    "Drafts" : "Borrolhons",
    "Archive" : "Archius",
    "Trash" : "Escobilhièr",
    "Junk" : "Indesirables",
    "All" : "Totes",
    "Favorites" : "Favorits",
    "Auto detect failed. Please use manual mode." : "L'autodeteccion a fracassat. Utilizatz lo mòde manual.",
    "Creating account failed: " : "La creacion del compte a fracassat :",
    "Delete permanently" : "Suprimir definitivament",
    "Error loading message" : "Error al moment del cargament del messatge",
    "Continue to %s" : "Contunhar cap a %s",
    "Connect" : "Connectar"
},
"nplurals=2; plural=(n > 1);");
